@@ -43,8 +43,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/evie/packages/python/python-3.10.0-0/Python-3.10.0/coverage.info',
- 'COVERAGE_REPORT': '/home/evie/packages/python/python-3.10.0-0/Python-3.10.0/lcov-report',
+ 'COVERAGE_INFO': '/home/evie/packages/python/python-3.10.2-0/Python-3.10.2/coverage.info',
+ 'COVERAGE_REPORT': '/home/evie/packages/python/python-3.10.2-0/Python-3.10.2/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -273,6 +273,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
@@ -364,6 +365,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -680,10 +682,9 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.0-0/Python-3.10.0',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.2-0/Python-3.10.2',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
@@ -723,14 +724,15 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.0-0/Python-3.10.0 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.2-0/Python-3.10.2 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.0-0/Python-3.10.0 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/evie/packages/python/python-3.10.2-0/Python-3.10.2 '
                './python ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
@@ -753,8 +755,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/evie/packages/python/python-3.10.0-0/Python-3.10.0',
- 'abs_srcdir': '/home/evie/packages/python/python-3.10.0-0/Python-3.10.0',
+ 'abs_builddir': '/home/evie/packages/python/python-3.10.2-0/Python-3.10.2',
+ 'abs_srcdir': '/home/evie/packages/python/python-3.10.2-0/Python-3.10.2',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
